package VMOMI::ClusterDasVmSettingsIsolationResponse;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
